Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3207)

Unified Diff: chrome/browser/instant/instant_controller.h

Issue 11359198: Implement the Instant extended API startMargin, endMargin, and rtl properties and the onmarginchang… (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/instant/instant_controller.h
diff --git a/chrome/browser/instant/instant_controller.h b/chrome/browser/instant/instant_controller.h
index 7c9f11c834bf9191966b2bb3bd1ce88cf990caac..6e08215b4325763e1576e8e7517f39765f283008 100644
--- a/chrome/browser/instant/instant_controller.h
+++ b/chrome/browser/instant/instant_controller.h
@@ -91,7 +91,10 @@ class InstantController {
const string16& full_text,
bool verbatim);
- // Sets the bounds of the omnibox dropdown, in screen coordinates.
+ // Sets the bounds of the omnibox popup, in screen coordinates.
+ void SetPopupBounds(const gfx::Rect& bounds);
dhollowa 2012/11/14 17:20:46 Are both the popup bounds and omnibox bounds still
samarth 2012/11/14 19:02:04 I think we want omnibox bounds and not popup bound
melevin 2012/11/14 22:16:27 We might want to do this in a separate change. The
dhollowa 2012/11/14 22:53:56 We shouldn't really be setting/sending full "bound
melevin 2012/11/15 23:40:01 I've split the bounds into separate start and end
+
+ // Sets the bounds of the omnibox itself, in screen coordinates.
void SetOmniboxBounds(const gfx::Rect& bounds);
// Send autocomplete results from |providers| to the preview page.
@@ -208,7 +211,7 @@ class InstantController {
// the given |height|.
void Show(InstantShownReason reason, int height, InstantSizeUnits units);
// Send the omnibox dropdown bounds to the page.
void SendBoundsToPage();
// If |template_url| is a valid TemplateURL for use with Instant, fills in
@@ -253,12 +256,15 @@ class InstantController {
// True if the active tab in the current window is the NTP, false otherwise.
bool active_tab_is_ntp_;
+ // Current omnibox popup bounds.
dhollowa 2012/11/14 17:20:46 Would it be possible to eliminate this "cache" of
melevin 2012/11/14 22:16:27 I don't think so. We need at least one additional
+ gfx::Rect popup_bounds_;
+
+ // Last popup bounds passed to the page.
+ gfx::Rect last_popup_bounds_;
+
// Current omnibox bounds.
gfx::Rect omnibox_bounds_;
- // Last bounds passed to the page.
- gfx::Rect last_omnibox_bounds_;
-
// Timer used to update the bounds of the omnibox.
base::OneShotTimer<InstantController> update_bounds_timer_;
« no previous file with comments | « no previous file | chrome/browser/instant/instant_controller.cc » ('j') | chrome/browser/ui/omnibox/omnibox_edit_model.cc » ('J')
@@ -208,7 +211,7 @@ class InstantController {
// the given |height|.
void Show(InstantShownReason reason, int height, InstantSizeUnits units);
- // Send the omnibox dropdown bounds to the page.
+ // Send the omnibox popup bounds to the page.
void SendBoundsToPage();
// If |template_url| is a valid TemplateURL for use with Instant, fills in

Powered by Google App Engine
This is Rietveld 408576698